from GitMarco import energy, utils, tf
import logging

logging.basicConfig(format='GitMarco - %(levelname)s: %(message)s',
                    level=logging.INFO)
